#!/usr/bin/perl -w

use Text::CSV;
use Date::Parse;
use Date::Format;

=head COPYRIGHT

Copyright (C) 2007 David Lee Lambert.

  Permission to use, copy, modify, and distribute this software and its
  documentation for any purpose, without fee, and without a written agreement
  is hereby granted, provided that the above copyright notice and this
  paragraph and the following two paragraphs appear in all copies.
  
  IN NO EVENT SHALL David Lee Lambert BE LIABLE TO ANY PARTY FOR
  DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
  LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS
  DOCUMENTATION, EVEN IF THE David Lee Lambert HAS BEEN ADVISED OF THE
  POSSIBILITY OF SUCH DAMAGE.
  
  David Lee Lambert SPECIFICALLY DISCLAIMS ANY WARRANTIES,
  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
  ON AN "AS IS" BASIS, AND THE David Lee Lambert HAS NO OBLIGATIONS TO
  PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.

=head PURPOSE

Change the file exported by the Yahoo! calendar into a form that can be
imported by a PHPGroupWare calendar.

=cut

$csv = Text::CSV_XS->new();


open IN, "Yahoo.csv" or die;

open OUT,">Yahoo.ical" or die;

<IN>;

print OUT "BEGIN:VCALENDAR\n".
    "VERSION:2.0\n".
    "PRODID:-//lmert.com//y2cal.pl//NONSGML v1.0//EN\n";

while (<IN>) {

    (warn "not a CSV line: $_", next) unless $csv->parse($_);
    ($subject, 
     $startdate, $starttime, 
     $enddate, $endtime,
     $allday, $desc ) = $csv->fields();

    if (defined($startdate) and $startdate =~ m!\d+/\d+/\d+!) {
	if (defined($starttime) and $starttime =~ m!\d+:\d+!) {
	    $start = time2str("%Y%m%dT%H%M%SZ",str2time($startdate." ".$starttime,"EST"));
	} else {
	    $start = time2str("%Y%m%dT%H%M%SZ",str2time($startdate));
	}
    } else {
	undef $start;
    }


    if (defined($enddate) and $enddate =~ m!\d+/\d+/\d+!) {
	if (defined($endtime) and $endtime =~ m!\d+:\d+!) {
	    $end = time2str("%Y%m%dT%H%M%SZ",str2time($enddate." ".$endtime,"EST"));
	} else {
	    $end = time2str("%Y%m%dT%H%M%SZ",str2time($enddate));
	}
    } else {
	undef $end;
    }

    print STDERR "$startdate,$starttime,$enddate,$endtime -> $start,$end\n";

    print OUT "BEGIN:VEVENT\n";

    print OUT "DTSTART:$start\n" if defined($start);
    print OUT "DTEND:$end\n"     if defined($end);

    print OUT "SUMMARY:$subject\n"   if defined($subject) and $subject =~ m/\S/;

    print OUT "DESCRIPTION:$desc\n"  if defined($desc) and $desc =~ m/\S/;

    print OUT "END:VEVENT\n";

}


print OUT "END:VCALENDAR\n";
    
    
